package cn.estsh.i3plus.ext.mes.apiservice.schedulejob;


import cn.estsh.i3plus.ext.mes.api.base.IMesCorssOrganizeErrorProofingService;
import cn.estsh.i3plus.mes.apiservice.schedulejob.BaseMesScheduleJob;
import cn.estsh.i3plus.platform.common.tool.JsonUtilTool;
import cn.estsh.i3plus.pojo.model.wms.WmsJobParamModel;
import cn.estsh.impp.framework.boot.init.ApplicationProperties;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.quartz.DisallowConcurrentExecution;
import org.quartz.JobExecutionContext;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.util.List;

/**
 * @Description : 跨工厂防错JOB
 * @Reference :
 * @Author : junsheng.li
 * @CreateDate 2024/7/5 11:07
 * @Modify:
 **/
@Slf4j
@DisallowConcurrentExecution
@Component
@ApiOperation("跨工厂防错JOB")
public class MesCorssOrganizeErrorProofingJob extends BaseMesScheduleJob {

    @Autowired
    private IMesCorssOrganizeErrorProofingService mesCorssOrganizeErrorProofingService;

    public MesCorssOrganizeErrorProofingJob() {
        super(MesCorssOrganizeErrorProofingJob.class, "跨工厂防错JOB");
    }

    @Override
    public void executeMesJob(JobExecutionContext context, ApplicationProperties applicationProperties) {
        List<WmsJobParamModel> wmsJobParamModelList = JsonUtilTool.toList(this.getJobParam(), WmsJobParamModel.class);
        if (!CollectionUtils.isEmpty(wmsJobParamModelList)) {
            for (WmsJobParamModel wmsJobParamModel : wmsJobParamModelList) {
                //统计数据
                try {
                    long startTime = System.currentTimeMillis();
                    mesCorssOrganizeErrorProofingService.doMesCorssOrganizeErrorProofing(wmsJobParamModel.getOrganizeCode(), wmsJobParamModel.getPageSize(), "job");
                    long endTime = System.currentTimeMillis();
                    log.info("工厂{}跨工厂防错job --- END --- 耗时: {} ms", wmsJobParamModel.getOrganizeCode(), endTime - startTime);
                } catch (Exception e) {
                    log.info("工厂{}跨工厂防错job 执行失败{}", wmsJobParamModel.getOrganizeCode(), e);
                }
            }
        }
    }

}
